@@ -15,7 +15,6 @@ import pgclibrary.utilities.*;
 public class SequencePanel extends JTabbedPane {
     Sequence sequence_object = null;
     
-    JTextField oid = new JTextField(20);
     JTextField name = new JTextField(20);
     JTextField creator = new JTextField(20);
     JTextArea description = new JTextArea(3, 20);
@@ -47,7 +46,6 @@ public class SequencePanel extends JTabbedPane {
     }
     
     private void insertDefaultTab() {
-        oid.setEditable(false);
         name.setEditable(false);
         creator.setEditable(false);
         increment.setEditable(false);
@@ -55,8 +53,8 @@ public class SequencePanel extends JTabbedPane {
         max.setEditable(false);
         min.setEditable(false);
         description.setEditable(false);
-        description.setBorder(oid.getBorder());
-        description.setBackground(oid.getBackground());
+        description.setBorder(name.getBorder());
+        description.setBackground(name.getBackground());
         description.setLineWrap(true);
         JScrollPane dpane = new JScrollPane(description);
         dpane.setPreferredSize(description.getPreferredSize());
@@ -70,7 +68,6 @@ public class SequencePanel extends JTabbedPane {
         
         JPanel general_panel = new JPanel();
         general_panel.setLayout(new BoxLayout(general_panel, BoxLayout.Y_AXIS));
-        general_panel.add(SUtilities.getHorPanel("Sequence ID :", oid));
         general_panel.add(SUtilities.getHorPanel("Sequence Name :", name));
         general_panel.add(SUtilities.getHorPanel("Creator :", creator));
         general_panel.add(SUtilities.getHorPanel("Description :",dpane));
@@ -84,7 +81,6 @@ public class SequencePanel extends JTabbedPane {
     }
     
     private void refreshDefaultPanel(){
-        oid.setText(String.valueOf(sequence_object.getOID()));
         name.setText(sequence_object.getName());
         sql.setText(sequence_object.getInsertSQL());
         creator.setText(sequence_object.getCreator().getName());
