@@ -36,7 +36,9 @@ public class AttributeType {
                 size = rs.getInt("TYPLEN");
                 retorno = true;
             }
-        } catch (Exception e){}
+    } catch (Exception e){
+            e.printStackTrace();
+        }
         return retorno;
     }
     
