@@ -19,9 +19,9 @@ public class Group extends DBObject {
     
     
     /** Creates a new instance of Group */
-    public Group(DBObject owner, long oid) {
+    public Group(DBObject owner, String _name) {
         super(owner);
-        search(oid);
+        search(_name);
     }
     public Group(DBObject owner) {
         super(owner);
@@ -59,19 +59,18 @@ public class Group extends DBObject {
         return new String();
     }
     
-    /** Find the object asociated with the OID.
-     * @param _oid OID to search.
+    /** Find the object asociated with the name.
+     * @param _name Group Name to search.
      * @return true if the object was found
      */
-    public boolean search(long _oid) {
+    public boolean search(String _name) {
         boolean retorno = false;
         try{
             initialize();
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID, * FROM PG_GROUP WHERE OID=?");
-            prep.setLong(1, _oid);
+            PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM PG_GROUP WHERE GRONAME=?");
+            prep.setString(1, _name);
             ResultSet rs = prep.executeQuery();
             if(rs.next()){
-                setOID(rs.getLong("OID"));
                 setName(rs.getString("GRONAME"));
                 setUsers(rs.getArray("GROLIST"));
                 retorno = true;
@@ -79,6 +78,7 @@ public class Group extends DBObject {
             rs.close();
             prep.close();
         } catch (SQLException e){
+            e.printStackTrace();
         }
         return retorno;;
     }
@@ -93,7 +93,7 @@ public class Group extends DBObject {
     private int getUserIndex(User _user){
         int retorno = -1;
         for(int i=0; (i<users.size()) && (retorno == -1); i++){
-            if(_user.getOID() == ((User) users.get(i)).getOID()){
+            if(_user.getName().equals(((User) users.get(i)).getName())){
                 retorno = i;
             }
         }
@@ -157,15 +157,15 @@ public class Group extends DBObject {
         try{
             user_list = (int[]) _users.getArray();
         } catch (SQLException e){
+            e.printStackTrace();
             user_list = null;
         }
     }
     
     /** refresh the data from database.
-     * if oid>0. Elsewere no action.
      */
     public void refresh() {
-        search(getOID());
+        search(getName());
     }
     
 }
