@@ -21,6 +21,7 @@ public class User extends DBObject {
     private boolean user_super = false;
     private boolean user_captupd = false;
     private java.util.Date user_valuntil = null;
+    private long oid = -1;
     
     /** Creates a new instance of User */
     public User(DBObject _owner, long _oid) {
@@ -92,7 +93,7 @@ public class User extends DBObject {
             ResultSet rs = prep.executeQuery();
             if(rs.next()){
                 setName(rs.getString("USENAME"));
-                setOID(rs.getLong("USESYSID"));
+                oid = rs.getLong("USESYSID");
                 setDBCreator(rs.getBoolean("USECREATEDB"));
                 setTraceUser(rs.getBoolean("USECREATEDB"));
                 setSuperUser(rs.getBoolean("USECREATEDB"));
@@ -103,6 +104,7 @@ public class User extends DBObject {
             rs.close();
             prep.close();
         } catch (SQLException e){
+            e.printStackTrace();
         }
         return retorno;
     }
@@ -176,10 +178,9 @@ public class User extends DBObject {
     }
     
     /** refresh the data from database.
-     * if oid>0. Elsewere no action.
-     */
+       */
     public void refresh() {
-        search(getOID());
+        search(oid);
     }
     
 }
