@@ -22,18 +22,18 @@ public class DatabaseList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID FROM pg_database ORDER BY DATNAME");
+            PreparedStatement prep = getConnection().prepareStatement("SELECT DATNAME FROM pg_database ORDER BY DATNAME");
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
-                addProperty(new Element(this, new Database(getConnection(), rs.getLong("OID"))));
+                addProperty(new Element(this, new Database(getConnection(), rs.getString("DATNAME"))));
             }
             rs.close();
             prep.close();
         } catch (SQLException e){}
     }
     
-    public long getOID() {
-        return -1;
+    public Object getOID() {
+        return toString();
     }
     
     public String toString(){
