@@ -22,17 +22,17 @@ public class GroupList extends TreeInfo {
         setIcon("/images/group.gif");
     }
     
-    public long getOID() {
-        return -3;
+    public Object getOID() {
+        return toString();
     }
     
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID FROM PG_GROUP");
+            PreparedStatement prep = getConnection().prepareStatement("SELECT GRONAME FROM PG_GROUP");
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
-                addProperty(new Element(this, new Group(getDatabase(), rs.getLong("OID"))));
+                addProperty(new Element(this, new Group(getDatabase(), rs.getString("GRONAME"))));
             }
             rs.close();
             prep.close();
