@@ -31,8 +31,8 @@ public class RootElement extends TreeInfo {
         database = _database;
     }
     
-    public long getOID() {
-        return 0;
+    public Object getOID() {
+        return "root";
     }
     
     public void rebuildProperties() {
