@@ -25,18 +25,18 @@ public class SequenceList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID FROM PG_CLASS WHERE RELKIND='S' ORDER BY RELNAME");
+            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='S' ORDER BY RELNAME");
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
-                addProperty(new Element(this, new Sequence(getDatabase(), rs.getLong("OID"))));
+                addProperty(new Element(this, new Sequence(getDatabase(), rs.getString("RELNAME"))));
             }
             rs.close();
             prep.close();
         } catch (SQLException e){}
     }
     
-    public long getOID() {
-        return -2;
+    public Object getOID() {
+        return toString();
     }
     
     public String toString(){
