@@ -22,17 +22,17 @@ public class TableList extends TreeInfo {
         setIcon("/images/table.png");
     }
     
-    public long getOID() {
-        return -3;
+    public Object getOID() {
+        return toString();
     }
     
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID FROM PG_CLASS WHERE RELKIND='r' ORDER BY RELNAME");
+            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='r' ORDER BY RELNAME");
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
-                addProperty(new Element(this, new Table(getDatabase(), rs.getLong("OID"))));
+                addProperty(new Element(this, new Table(getDatabase(), rs.getString("RELNAME"))));
             }
             rs.close();
             prep.close();
