@@ -36,8 +36,8 @@ public class UserList extends TreeInfo {
         }
     }
     
-    public long getOID() {
-        return -4;
+    public Object getOID() {
+        return toString();
     }
     
     public String toString(){
