@@ -25,10 +25,10 @@ public class ViewList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT OID FROM PG_CLASS WHERE RELKIND='v' ORDER BY RELNAME");
+            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='v' ORDER BY RELNAME");
             ResultSet rs = prep.executeQuery();
             while(rs.next()){
-                addProperty(new Element(this, new View(getDatabase(), rs.getLong("OID"))));
+                addProperty(new Element(this, new View(getDatabase(), rs.getString("RELNAME")))); 
             }
             rs.close();
             prep.close();
@@ -36,8 +36,8 @@ public class ViewList extends TreeInfo {
         }
     }
     
-    public long getOID() {
-        return -5;
+    public Object getOID() {
+        return toString();
     }
     
     public String toString(){
